@@ -36,7 +36,8 @@
 #include <ETL/stringf>
 #include <algorithm>
 #include <cmath>
-#include <inttypes.h>
+
+#include <synfig/general.h>
 
 #endif
 
@@ -117,13 +118,13 @@ Bone::set_parent(const ValueNode_Bone* parent)
 //!@return The tip Point of the bone (calculated) based on
 //! tip=origin+[length,0]*Scalex(scalex*scalelx,0)*Rotate(alpha)
 Point
-Bone::get_tip()
+Bone::get_tip() const
 {
 	Matrix s, r, sr;
 	s.set_scale(scalex_*scalelx_,0);
 	r.set_rotate(angle_);
 	sr=s*r;
-	return (Point)sr.get_transformed(Vector(length_,0));
+	return static_cast<Point>(sr.get_transformed(Vector(length_,0)));
 }
 
 //!Get the string of the Bone
@@ -132,17 +133,20 @@ Bone::get_tip()
 synfig::String
 Bone::get_string()const
 {
-	return strprintf("N=%s O=(%.4f %.4f) a=%.4f slx=%.4f sx=%.4f l=%.4f w=%.4f tw=%.4f or=%.4f P=%lx",
+	return strprintf("N=%s O=(%.4f %.4f) a=%.4f slx=%.4f sx=%.4f l=%.4f w=%.4f tw=%.4f or=%.4f P=%p",
 					 name_.c_str(),
 					 origin_[0], origin_[1],
 					 Angle::deg(angle_).get(),
-					 scalelx_, scalex_, length_, width_, tipwidth_, depth_, uintptr_t(parent_));
+					 scalelx_, scalex_, length_, width_, tipwidth_, depth_, parent_);
 }
 
 bool
 Bone::is_root()const
 {
-	return get_parent()->is_root();
+	if (parent_)
+		return get_parent()->is_root();
+	synfig::warning("should not reach this line in Bone::is_root()");
+	return true;
 }
 
 Bone::Shape
